package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.UtilsMapper;
import com.steerinfo.dil.service.IUtilsService;
import com.steerinfo.dil.util.DataChange;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTIgnoredError;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/10/26 14:42
 */

@Service(value = "utilsService")
public class UtilsServiceImpl implements IUtilsService {
    @Autowired
    private UtilsMapper utilsMapper;

    /**
     * 查询运输订单ID主键
     * @return
     */
    @Override
    public BigDecimal selectOrderMaxId() {
        return utilsMapper.selectOrderMaxId();
    }

    /**
     * 查询运输订单子表主键ID
     * @return
     */
    @Override
    public BigDecimal selectOrderMaterialMaxId() {
        return utilsMapper.selectOrderMaterialMaxId();
    }

    /**
     * 修改运力状态
     * @param map {必要参数：capacityId 运力ID  或者 capacityNumber 车牌号}
     * @param status 类型
     * @return
     */
    public int updateCapacityStatus(Map<String, Object> map, Integer status){
        map.put("capacityStatus", status);
        return  utilsMapper.updateCapacityByCarIdOrNum(map);
    }


    /**
     * 修改订单状态为结束
     * @param map {orderId 订单Id
     * @return
     */
    public int updateOrderStatus(Map<String, Object> map, Integer status){
        map.put("orderStatus", status);
        return utilsMapper.updateOrderStatusByOrderIdOrNum(map);
    }

    /**
     * 通过仓库名称查询仓库Id
     * @param warehouseName
     * @return
     */
    @Override
    public Integer queryWarehouseIdByName(String warehouseName) {
        return utilsMapper.queryWarehouseIdByName(warehouseName);
    }

    /**
     * 用于更新路段顺序号
     * @param map 运输订单号 或者是运输订单ID
     * @return
     */
    public int updateOrderLineSequence(Map<String, Object> map, Integer num){
        BigDecimal orderId = DataChange.dataToBigDecimal(map.get("orderId"));
        if(orderId.intValue() == 0){
            //如果没有传入运输订单Id则需要传入了运输订单号
            orderId = utilsMapper.getOrderIdByOrderNumber((String) map.get("orderNumber"));
        }
        Integer lineSequence = getLineSequenceByOrderId(orderId);
        Map<String, Object> mesMap = new HashMap<>();
        mesMap.put("orderId", orderId);
        mesMap.put("orderLineSequence", lineSequence == null? 1 : lineSequence + num);
        return utilsMapper.updateLineSeqByOrderIdOrNum(mesMap);
    }

    /**
     * 通过月台名称查询月台Id
     * @param platformName
     * @return
     */
    @Override
    public Integer queryPlatformIdByName(String platformName) {
        return utilsMapper.queryPlatformIdByName(platformName);
    }

    /**
     * 查询路段顺序号
     * @param orderId
     * @return
     */
    @Override
    public Integer getLineSequenceByOrderId(BigDecimal orderId) {
        return utilsMapper.getLineSequenceByOrderId(orderId);
    }

    /**
     * 查询订单中所需要运输的物资  物资表对订单表 一对多
     * @param map 运输订单号 orderNumber
     * @return
     */
    @Override
    public List<Integer> getAllMaterialId(Map<String, Object> map) {
        return utilsMapper.getAllMaterialId(map);
    }


    /**
     * 通过总实绩ID查询订单Id
     * @param resultTotalId
     * @return
     */
    @Override
    public Integer getOrderIdByTotalId(Integer resultTotalId) {
        return utilsMapper.getOrderIdByTotalId(resultTotalId);
    }


}
